import { SplineType_$type } from "./SplineType";
import { IgrHorizontalAnchoredCategorySeries } from "./igr-horizontal-anchored-category-series";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents the base class for all IgxDataChartComponent spline series.
*/
export class IgrSplineSeriesBase extends IgrHorizontalAnchoredCategorySeries {
    constructor(props) {
        super(props);
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets whether the current series shows an area or line shape.
    */
    get isAreaOrLine() {
        return this.i.cy;
    }
    /**
     * Gets or sets the type of spline to be rendered.
    *
    * ```ts
    * this.series.splineType = SplineType.Clamped;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource} >
    *
    *     <IgrCategoryXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrSplineAreaSeries
    *      name="series1"
    *      valueMemberPath="value"/>
    *  </IgrDataChart>
    * ```
    */
    get splineType() {
        return this.i.s8;
    }
    set splineType(v) {
        this.i.s8 = ensureEnum(SplineType_$type, v);
    }
}
//# sourceMappingURL=igr-spline-series-base.js.map
