import * as tslib_1 from "tslib";
import { IgrSizeScale } from "./igr-size-scale";
import { IgrBrushScale } from "./igr-brush-scale";
import { IgrScatterBase } from "./igr-scatter-base";
import { BubbleSeries } from "./BubbleSeries";
import { ensureBool } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent bubble series.
*/
var IgrBubbleSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(IgrBubbleSeries, _super);
    function IgrBubbleSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrBubbleSeries.prototype.createImplementation = function () {
        return new BubbleSeries();
    };
    Object.defineProperty(IgrBubbleSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "radiusMemberPath", {
        /**
         * Gets or sets the radius mapping property for the current series object.
        */
        get: function () {
            return this.i.tr;
        },
        set: function (v) {
            this.i.tr = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "radiusScale", {
        /**
         * Gets or sets the radius size scale for the bubbles.
        */
        get: function () {
            if (this.i.sz == null) {
                return null;
            }
            if (!this.i.sz.externalObject) {
                var e = IgrSizeScale._createFromInternal(this.i.sz);
                if (e) {
                    e._implementation = this.i.sz;
                }
                this.i.sz.externalObject = e;
            }
            return this.i.sz.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.sz = null : this.i.sz = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "labelMemberPath", {
        /**
         * Gets or sets the Label mapping property for the current series object.
        */
        get: function () {
            return this.i.tl;
        },
        set: function (v) {
            this.i.tl = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "fillMemberPath", {
        /**
         * Gets or sets the fill mapping property for the current series object.
        */
        get: function () {
            return this.i.tg;
        },
        set: function (v) {
            this.i.tg = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "fillScale", {
        /**
         * Gets or sets the brush scale for the fill brush of markers.
        */
        get: function () {
            if (this.i.sx == null) {
                return null;
            }
            if (!this.i.sx.externalObject) {
                var e = IgrBrushScale._createFromInternal(this.i.sx);
                if (e) {
                    e._implementation = this.i.sx;
                }
                this.i.sx.externalObject = e;
            }
            return this.i.sx.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.sx = null : this.i.sx = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "fillScaleUseGlobalValues", {
        /**
         * Gets or sets whether or not the FillScale uses global min/max values of FillMemberPath from multiple series.
         * This setting applies only if multiple series are using the same FillScale.
        */
        get: function () {
            return this.i.s7;
        },
        set: function (v) {
            this.i.s7 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "markerOutlineUsesFillScale", {
        /**
         * Gets or sets whether or not the marker outline should use FillScale like the marker fill does.
         * This setting applies only if the current series has a FillScale set and it overrides MarkerOutline setting.
        */
        get: function () {
            return this.i.s8;
        },
        set: function (v) {
            this.i.s8 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "markerOutlineBrightness", {
        /**
         * Gets or sets brightness of the marker outline. Using negative value will change marker outline to darker color and positive value will change marker outline to brighter color
         * Note you can use any values between minimum value of -1 (darkest outline) and maximum value of 1 (brightest outline)
        */
        get: function () {
            return this.i.te;
        },
        set: function (v) {
            this.i.te = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "markerBrushBrightness", {
        /**
         * Gets or sets brightness of the marker fill. Using negative value will change marker fill to darker color and positive value will change marker fill to brighter color
         * Note you can use any values between minimum value of -1 (darkest fill) and maximum value of 1 (brightest fill)
        */
        get: function () {
            return this.i.td;
        },
        set: function (v) {
            this.i.td = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "radiusScaleUseGlobalValues", {
        /**
         * Gets or sets the whether or not the RadiusScale uses global values of RadiusMemberPath from multiple series.
         * This setting applies only if multiple series are using the same RadiusScale.
        */
        get: function () {
            return this.i.s9;
        },
        set: function (v) {
            this.i.s9 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBubbleSeries.prototype, "isMarkerlessDisplayPreferred", {
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get: function () {
            return this.i.dd;
        },
        enumerable: true,
        configurable: true
    });
    IgrBubbleSeries.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.radiusScale && this.radiusScale.name && this.radiusScale.name == name) {
            return this.radiusScale;
        }
        if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
            return this.fillScale;
        }
        return null;
    };
    IgrBubbleSeries.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.radiusScale && this.radiusScale._styling) {
            this.radiusScale._styling(container, component, this);
        }
        if (this.fillScale && this.fillScale._styling) {
            this.fillScale._styling(container, component, this);
        }
        this._inStyling = false;
    };
    IgrBubbleSeries.prototype.getItemValue = function (item, memberPathName) {
        var iv = this.i.gt(item, memberPathName);
        return (iv);
    };
    return IgrBubbleSeries;
}(IgrScatterBase));
export { IgrBubbleSeries };
//# sourceMappingURL=igr-bubble-series.js.map
