import { IgrAxis } from "./igr-axis";
import { IgrAnnotationLayer, IIgrAnnotationLayerProps } from "./igr-annotation-layer";
import { CategoryToolTipLayer } from "./CategoryToolTipLayer";
/**
 * Represents an annotation layer that displays grouped tooltips for series that use a category axis.
*/
export declare class IgrCategoryToolTipLayer extends IgrAnnotationLayer<IIgrCategoryToolTipLayerProps> {
    protected createImplementation(): CategoryToolTipLayer;
    /**
                                 * @hidden
                                 */
    readonly i: CategoryToolTipLayer;
    constructor(props: IIgrCategoryToolTipLayerProps);
    /**
     * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
    */
    readonly isDefaultTooltipBehaviorDisabled: boolean;
    /**
     * Gets or sets the Axis to target this annotation to. If null, this annotation layer will not render content.
    */
    targetAxis: IgrAxis;
    /**
     * Gets or sets whether to use value interpolation when drawing the tooltips.
    */
    useInterpolation: boolean;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTips(): void;
}
export interface IIgrCategoryToolTipLayerProps extends IIgrAnnotationLayerProps {
    /**
     * Gets or sets the Axis to target this annotation to. If null, this annotation layer will not render content.
    */
    targetAxis?: IgrAxis;
    /**
     * Gets or sets whether to use value interpolation when drawing the tooltips.
    */
    useInterpolation?: boolean | string;
}
