import { ColorScaleInterpolationMode } from "./ColorScaleInterpolationMode";
import { IgrColorScale, IIgrColorScaleProps } from "./igr-color-scale";
import { CustomPaletteColorScale } from "./CustomPaletteColorScale";
/**
 * ColorScale class for selecting a color from a given palette, or interpolating between adjacent colors in that palette.
*/
export declare class IgrCustomPaletteColorScale extends IgrColorScale<IIgrCustomPaletteColorScaleProps> {
    protected createImplementation(): CustomPaletteColorScale;
    /**
                                 * @hidden
                                 */
    readonly i: CustomPaletteColorScale;
    constructor(props: IIgrCustomPaletteColorScaleProps);
    /**
     * The lowest value to assign a color.  Any given value less than this value will be made Transparent.
    */
    minimumValue: number;
    /**
     * The highest value to assign a color.  Any given value greater than this value will be made Transparent.
    */
    maximumValue: number;
    /**
     * A list of colors to select from or interpolate between.
    */
    palette: string[];
    /**
     * The approach to use when getting a color from the palette.
    */
    interpolationMode: ColorScaleInterpolationMode;
    providePalette(colors: string[]): void;
}
export interface IIgrCustomPaletteColorScaleProps extends IIgrColorScaleProps {
    /**
     * The lowest value to assign a color.  Any given value less than this value will be made Transparent.
    */
    minimumValue?: number | string;
    /**
     * The highest value to assign a color.  Any given value greater than this value will be made Transparent.
    */
    maximumValue?: number | string;
    /**
     * A list of colors to select from or interpolate between.
    */
    /**
     * The approach to use when getting a color from the palette.
    */
    interpolationMode?: ColorScaleInterpolationMode | string;
}
