import { IgrSeries } from "./igr-series";
import { IgrAnnotationLayer, IIgrAnnotationLayerProps } from "./igr-annotation-layer";
import { ItemToolTipLayer } from "./ItemToolTipLayer";
/**
 * Represents an annotation layer that displays tooltips for all target series individually.
*/
export declare class IgrItemToolTipLayer extends IgrAnnotationLayer<IIgrItemToolTipLayerProps> {
    protected createImplementation(): ItemToolTipLayer;
    /**
                                 * @hidden
                                 */
    readonly i: ItemToolTipLayer;
    constructor(props: IIgrItemToolTipLayerProps);
    /**
     * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
    */
    readonly isDefaultTooltipBehaviorDisabled: boolean;
    /**
     * Gets or sets the name of the series series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    targetSeriesName: string;
    /**
     * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    targetSeries: IgrSeries;
    /**
     * Gets or sets whether to use value interpolation when drawing the tooltips.
    */
    useInterpolation: boolean;
    /**
     * Gets or sets whether to skip past unknown values when searching for series values.
    */
    skipUnknownValues: boolean;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTips(): void;
}
export interface IIgrItemToolTipLayerProps extends IIgrAnnotationLayerProps {
    /**
     * Gets or sets the name of the series series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    targetSeriesName?: string;
    /**
     * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    targetSeries?: IgrSeries;
    /**
     * Gets or sets whether to use value interpolation when drawing the tooltips.
    */
    useInterpolation?: boolean | string;
    /**
     * Gets or sets whether to skip past unknown values when searching for series values.
    */
    skipUnknownValues?: boolean | string;
}
