import { IgrStraightNumericAxisBase, IIgrStraightNumericAxisBaseProps } from "./igr-straight-numeric-axis-base";
import { NumericXAxis } from "./NumericXAxis";
/**
 * Represents a IgxDataChartComponent numeric X axis.
*
* The `IgrNumericXAxis` treats the data as continuously varying numerical data items. Labels on this axis are placed along the X-axis. The location of labels varies according to the value in a data column that is mapped using the `XMemberPath` property of Scatter Series or `ValueMemberPath` property of Bar Series.
*
* ```ts
*  <IgrDataChart
*     dataSource={this.state.dataSource} >
*
*     <IgrNumericXAxis name="xAxis" />
*     <IgrNumericYAxis name="yAxis"
* 		 crossingAxis= "xAxis"
* 		crossingValue= {700}/>
*  </IgrDataChart>
* ```
*
* ```ts
* this.series = new IgrColumnSeries({ name: "series1" });
* this.series.dataSource = this.data;
* this.series.xAxis = this.numericXAxis;
* this.series.yAxis = this.numericYAxis;
* this.series.xAxisName = "xAxis";
* this.series.yAxisName = "yAxis";
* ```
*/
export declare class IgrNumericXAxis extends IgrStraightNumericAxisBase<IIgrNumericXAxisProps> {
    protected createImplementation(): NumericXAxis;
    /**
                                 * @hidden
                                 */
    readonly i: NumericXAxis;
    constructor(props: IIgrNumericXAxisProps);
    scrollRangeIntoView(minimum: number, maximum: number): void;
}
export interface IIgrNumericXAxisProps extends IIgrStraightNumericAxisBaseProps {
}
